==> junit-quickcheck-generators-0.6-sources.jar: com/pholser/junit/quickcheck/generator/java/util/function/ToDoubleFunctionGenerator.java <==
/*
 The MIT License

 Copyright (c) 2010-2016 Paul R. Holser, Jr.

 Permission is hereby granted, free of charge, to any person obtaining
 a copy of this software and associated documentation files (the
 "Software"), to deal in the Software without restriction, including
 without limitation the rights to use, copy, modify, merge, publish,
 distribute, sublicense, and/or sell copies of the Software, and to
 permit persons to whom the Software is furnished to do so, subject to
 the following conditions:

 The above copyright notice and this permission notice shall be
 included in all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

package com.pholser.junit.quickcheck.generator.java.util.function;

import java.util.function.ToDoubleFunction;

import com.pholser.junit.quickcheck.generator.ComponentizedGenerator;
import com.pholser.junit.quickcheck.generator.GenerationStatus;
import com.pholser.junit.quickcheck.generator.java.lang.DoubleGenerator;
import com.pholser.junit.quickcheck.random.SourceOfRandomness;

import static com.pholser.junit.quickcheck.generator.Lambdas.*;

/**
 * Produces values of type {@link ToDoubleFunction}.
 *
 * @param <T> type of parameter of produced function
 */
public class ToDoubleFunctionGenerator<T> extends ComponentizedGenerator<ToDoubleFunction> {
    private final DoubleGenerator doubleGenerator = new DoubleGenerator();

    public ToDoubleFunctionGenerator() {
        super(ToDoubleFunction.class);
    }

    @SuppressWarnings("unchecked")
    @Override public ToDoubleFunction<T> generate(SourceOfRandomness random, GenerationStatus status) {
        return makeLambda(ToDoubleFunction.class, doubleGenerator, status);
    }

    @Override public int numberOfNeededComponents() {
        return 1;
    }
}

==> junit-quickcheck-generators-0.7-sources.jar: com/pholser/junit/quickcheck/generator/java/util/function/ToDoubleFunctionGenerator.java <==
/*
 The MIT License

 Copyright (c) 2010-2016 Paul R. Holser, Jr.

 Permission is hereby granted, free of charge, to any person obtaining
 a copy of this software and associated documentation files (the
 "Software"), to deal in the Software without restriction, including
 without limitation the rights to use, copy, modify, merge, publish,
 distribute, sublicense, and/or sell copies of the Software, and to
 permit persons to whom the Software is furnished to do so, subject to
 the following conditions:

 The above copyright notice and this permission notice shall be
 included in all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

package com.pholser.junit.quickcheck.generator.java.util.function;

import java.util.function.ToDoubleFunction;

import com.pholser.junit.quickcheck.generator.ComponentizedGenerator;
import com.pholser.junit.quickcheck.generator.GenerationStatus;
import com.pholser.junit.quickcheck.random.SourceOfRandomness;

import static com.pholser.junit.quickcheck.generator.Lambdas.*;

/**
 * Produces values of type {@link ToDoubleFunction}.
 *
 * @param <T> type of parameter of produced function
 */
public class ToDoubleFunctionGenerator<T> extends ComponentizedGenerator<ToDoubleFunction> {
    public ToDoubleFunctionGenerator() {
        super(ToDoubleFunction.class);
    }

    @SuppressWarnings("unchecked")
    @Override public ToDoubleFunction<T> generate(SourceOfRandomness random, GenerationStatus status) {
        return makeLambda(ToDoubleFunction.class, gen().type(double.class), status);
    }

    @Override public int numberOfNeededComponents() {
        return 1;
    }
}
